Display

Trait Display 

1.36.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Display for !



impl Display for Aborted

1.26.0 · Source

impl Display for AccessError



impl Display for AcquireError

1.4.0 · Source

impl Display for core::net::parser::AddrParseError



impl Display for AddrParseError



impl Display for AllocErr

Source

impl Display for AllocError



impl Display for ApplicationClose



impl Display for Arg

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for AsciiChar



impl Display for Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.



impl Display for Attribute



impl Display for Authority

1.65.0 · Source

impl Display for Backtrace



impl Display for BernoulliError



impl Display for BigEndian

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError



impl Display for BuildError



impl Display for BuildError

Source

impl Display for ByteStr

Source

impl Display for ByteString



impl Display for CFError



impl Display for CFString



impl Display for Canceled

Source

impl Display for Cancelled



impl Display for compio::ws::tungstenite::error::CapacityError



impl Display for CaseFoldError



impl Display for CastError<'_, '_>



impl Display for CastIntoError<'_>



impl Display for CertificateError

1.34.0 · Source

impl Display for CharTryFromError



impl Display for CheckedCastError

Available on non-SPIR-V only.


impl Display for ClearBuffer



impl Display for ClearLine



impl Display for CloseCode



impl Display for CloseFrame



impl Display for ClosedStream



impl Display for compio::quic::TransportErrorCode



impl Display for Code

Source

impl Display for CodecError



impl Display for CollectionAllocErr



impl Display for Color



impl Display for ColorChoice



impl Display for Command



impl Display for ConfigError



impl Display for ConnectError



impl Display for ConnectionClose

Source

impl Display for compio::quic::ConnectionError



impl Display for ConnectionError



impl Display for ConnectionError



impl Display for ConnectionErrorIncoming



impl Display for ConnectionId



impl Display for Control



impl Display for Data



impl Display for DecodeError



impl Display for DecodeKind

1.9.0 · Source

impl Display for DecodeUtf16Error



impl Display for DeserializeError



impl Display for DeserializeStateError



impl Display for Dir



impl Display for DisableCursorBlinking



impl Display for DisableMouseEvents

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>



impl Display for Display<'_>



impl Display for DowncastError<'_, '_>



impl Display for DowncastIntoError<'_>



impl Display for DummyBackendError



impl Display for EarlyDataError

Source

impl Display for compio::time::Elapsed



impl Display for Elapsed



impl Display for Empty



impl Display for EnableCursorBlinking



impl Display for EnableMouseEvents



impl Display for EncodeError



impl Display for EncryptError



impl Display for Errno



impl Display for Errno



impl Display for Errno

1.0.0 · Source

impl Display for compio::buf::bumpalo::core_alloc::io::Error

1.0.0 · Source

impl Display for compio::buf::bumpalo::core_alloc::fmt::Error

Source

impl Display for serde_core::de::value::Error

Source

impl Display for serde_json::error::Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for compio::tls::rustls::Error



impl Display for Error

Source

impl Display for getrandom::error::Error



impl Display for Error



impl Display for Error



impl Display for compio::ws::tungstenite::http::Error



impl Display for Error



impl Display for compio::tls::py_dynamic_openssl::error::Error



impl Display for compio::tls::py_dynamic_openssl::ssl::Error



impl Display for Error



impl Display for compio::tls::native_tls::Error



impl Display for compio::ws::tungstenite::Error



impl Display for Error



impl Display for Error



impl Display for Error

1.60.0 · Source

impl Display for compio::buf::bumpalo::core_alloc::io::ErrorKind



impl Display for ErrorKind



impl Display for ErrorKind



impl Display for ErrorKind



impl Display for ErrorOrigin



impl Display for ErrorStack

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode



impl Display for EventCategory

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError



impl Display for ExtendedKeyPurpose



impl Display for Field



impl Display for FieldSet



impl Display for FinishError



impl Display for Frame



impl Display for FrameError



impl Display for FrameType

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for compio::buf::bumpalo::core_alloc::slice::GetDisjointMutError



impl Display for GetDisjointMutError



impl Display for GetDisjointMutError



impl Display for Gid



impl Display for GroupInfoError



impl Display for HeaderError



impl Display for HeaderName



impl Display for HexSlice<'_>



impl Display for HideCursor



impl Display for Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.



impl Display for Id

1.34.0 · Source

impl Display for Infallible

1.7.0 · Source

impl Display for IntoStringError



impl Display for InvalidBufferSize



impl Display for InvalidChunkSize



impl Display for InvalidDnsNameError



impl Display for InvalidHeaderName



impl Display for InvalidHeaderValue



impl Display for InvalidKey



impl Display for InvalidLength



impl Display for InvalidMethod



impl Display for InvalidOutputSize



impl Display for InvalidPushId



impl Display for InvalidStatusCode



impl Display for InvalidStreamId



impl Display for InvalidUri



impl Display for InvalidUriParts

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

Source

impl Display for JoinError

1.0.0 · Source

impl Display for JoinPathsError



impl Display for KeyRejected

1.28.0 · Source

impl Display for LayoutError



impl Display for Level

Source

impl Display for log::Level



impl Display for LevelFilter

Source

impl Display for log::LevelFilter



impl Display for LittleEndian

1.26.0 · Source

impl Display for Location<'_>



impl Display for MatchError



impl Display for MatchesError



impl Display for MaxSizeReached



impl Display for Message



impl Display for Method



impl Display for MoveCursorDown



impl Display for MoveCursorLeft



impl Display for MoveCursorRight



impl Display for MoveCursorTo



impl Display for MoveCursorToColumn



impl Display for MoveCursorToNextLine



impl Display for MoveCursorToPreviousLine



impl Display for MoveCursorUp



impl Display for NoInitialCipherSuite

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for Number



impl Display for ObjectIdentifierRef



impl Display for OpCode

Source

impl Display for OpenStreamError



impl Display for OtherError



impl Display for PacketDecodeError

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError



impl Display for ParseError

1.0.0 · Source

impl Display for core::num::float_parse::ParseFloatError

Source

impl Display for num_traits::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError



impl Display for ParseLevelError

Source

impl Display for log::ParseLevelError



impl Display for ParseLevelFilterError



impl Display for PathAndQuery

Source

impl Display for PathPersistError



impl Display for PatternIDError



impl Display for PatternSetInsertError

Available on crate feature alloc only.


impl Display for Pid



impl Display for Pid

Available on crate feature process only.


impl Display for PodCastError

Available on non-SPIR-V only.


impl Display for PopError



impl Display for ProtocolError



impl Display for PushId



impl Display for PyBackedStr



impl Display for PyBorrowError



impl Display for PyBorrowMutError



impl Display for PyClassGuardError<'_, '_>



impl Display for PyClassGuardMutError<'_, '_>



impl Display for PyErr

Source

impl Display for compio::quic::ReadError



impl Display for ReadError

Source

impl Display for ReadExactError



impl Display for ReadableError

1.0.0 · Source

impl Display for std::sync::mpsc::RecvError



impl Display for RecvError



impl Display for RecvError



impl Display for RecvError



impl Display for RecvError



impl Display for RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError



impl Display for RecvTimeoutError



impl Display for Regex



impl Display for Regex



impl Display for ReportCursorPosition

Source

impl Display for ReserveError

Source

impl Display for ReserveExactError



impl Display for Reset



impl Display for ResetAttributes

Source

impl Display for ResetError



impl Display for ResizeTextArea



impl Display for RestoreCursorPosition



impl Display for RetryError



impl Display for ReuniteError



impl Display for ReuniteError



impl Display for SaveCursorPosition



impl Display for Scheme



impl Display for ScrollBufferDown



impl Display for ScrollBufferUp

Source

impl Display for compio::quic::SendDatagramError



impl Display for SendDatagramError



impl Display for SendDatagramError



impl Display for SendError

Source

impl Display for SerdeJsonCodecError



impl Display for SerializeError



impl Display for SetAttribute



impl Display for SetBackgroundColor



impl Display for SetForegroundColor



impl Display for SetGlobalDefaultError

Source

impl Display for SetLoggerError



impl Display for SettingsError



impl Display for ShowCursor



impl Display for Signal

Available on crate feature signal only.


impl Display for SmallIndexError

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6



impl Display for SpawnError



impl Display for SpecificationError

Available on crate feature alloc only.


impl Display for StateIDError



impl Display for StatusCode

Formats the status code, including the canonical reason.

Example

assert_eq!(format!("{}", StatusCode::OK), "200 OK");
Source

impl Display for StoppedError



impl Display for Str



impl Display for StreamError



impl Display for StreamErrorIncoming



impl Display for compio::quic::StreamId



impl Display for StreamId



impl Display for StreamType

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError



impl Display for Style



impl Display for StyledStr

Color-unaware printing. Never uses coloring.



impl Display for SubProtocolError



impl Display for SwitchBufferToAlternate



impl Display for SwitchBufferToNormal

1.8.0 · Source

impl Display for SystemTimeError



impl Display for ThreadPoolBuildError



impl Display for TimeSpec



impl Display for TimeVal



impl Display for TlsError

Source

impl Display for ToCasefold

1.16.0 · Source

impl Display for ToLowercase



impl Display for ToStrError

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase



impl Display for TryAcquireError

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError



impl Display for TryFromIteratorError

1.35.0 · Source

impl Display for core::array::TryFromSliceError



impl Display for TryFromSliceError



impl Display for TryGetError

1.89.0 · Source

impl Display for std::fs::TryLockError



impl Display for TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError

1.57.0 · Source

impl Display for compio::buf::bumpalo::core_alloc::collections::TryReserveError



impl Display for TryReserveError



impl Display for TryReserveError



impl Display for Uid



impl Display for UnexpectedEnd



impl Display for UnicodeWordBoundaryError



impl Display for UnicodeWordError

Source

impl Display for UnorderedKeyError



impl Display for Unspecified



impl Display for UnsupportedOperationError



impl Display for Uri



impl Display for UrlError



impl Display for Utf8Bytes

1.0.0 · Source

impl Display for Utf8Error

Source

impl Display for Value



impl Display for ValueRange



impl Display for ValueSet<'_>

1.0.0 · Source

impl Display for VarError



impl Display for compio::quic::VarInt



impl Display for VarInt



impl Display for VarIntBoundsExceeded



impl Display for VerifierBuilderError



impl Display for VersionError

Source

impl Display for WouldBlock

Source

impl Display for compio::quic::WriteError



impl Display for WriteError

1.56.0 · Source

impl Display for WriterPanicked

Source

impl Display for bf16

Available on non-SPIR-V only.
1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for dyn Expected + '_



impl Display for dyn Value

1.0.0 · Source

impl Display for f16

Source

impl Display for f16

Available on non-SPIR-V only.
1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize



impl<'a, I, F> Display for FormatWith<'a, I, F>
where I: Iterator, F: FnMut(<I as Iterator>::Item, &mut dyn FnMut(&dyn Display) -> Result<(), Error>) -> Result<(), Error>,



impl<'a, I> Display for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Display,



impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,



impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, T> Display for MappedMutexGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for MutexGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for Ref<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for Ref<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for RwLockReadGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for RwLockWriteGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for SpinMutexGuard<'a, T>
where T: Display + ?Sized,

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for compio::buf::bumpalo::core_alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for compio::buf::bumpalo::core_alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for compio::buf::bumpalo::core_alloc::str::EscapeUnicode<'a>

Source

impl<'a> Display for Unexpected<'a>



impl<'rwlock, T, R> Display for RwLockUpgradableGuard<'rwlock, T, R>
where T: Display + ?Sized,



impl<'rwlock, T, R> Display for RwLockWriteGuard<'rwlock, T, R>
where T: Display + ?Sized,



impl<'rwlock, T> Display for RwLockReadGuard<'rwlock, T>
where T: Display + ?Sized,



impl<'s, T> Display for SliceVec<'s, T>
where T: Display,



impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.



impl<A> Display for ArrayVec<A>
where A: Array, <A as Array>::Item: Display,



impl<A> Display for TinyVec<A>
where A: Array, <A as Array>::Item: Display,

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,



impl<E> Display for AllocOrInitError<E>
where E: Display,



impl<E> Display for DrawingAreaErrorKind<E>
where E: Error + Send + Sync,



impl<E> Display for DrawingErrorKind<E>
where E: Error + Send + Sync,

Source

impl<E> Display for Report<E>
where E: Error,



impl<F> Display for Error<F>
where F: ErrorFormatter,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<F> Display for PersistError<F>



impl<I> Display for ExactlyOneError<I>
where I: Iterator,



impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,



impl<O> Display for F32<O>
where O: ByteOrder,



impl<O> Display for F64<O>
where O: ByteOrder,



impl<O> Display for I16<O>
where O: ByteOrder,



impl<O> Display for I32<O>
where O: ByteOrder,



impl<O> Display for I64<O>
where O: ByteOrder,



impl<O> Display for I128<O>
where O: ByteOrder,



impl<O> Display for Isize<O>
where O: ByteOrder,



impl<O> Display for U16<O>
where O: ByteOrder,



impl<O> Display for U32<O>
where O: ByteOrder,



impl<O> Display for U64<O>
where O: ByteOrder,



impl<O> Display for U128<O>
where O: ByteOrder,



impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,



impl<Role> Display for compio::ws::tungstenite::HandshakeError<Role>
where Role: HandshakeRole,



impl<S> Display for compio::tls::native_tls::HandshakeError<S>
where S: Any + Debug,



impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.



impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.



impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,



impl<T, B> Display for Ref<B, T>
where B: ByteSlice, T: FromBytes + Display + KnownLayout + Immutable + ?Sized,



impl<T, E> Display for TryChunksError<T, E>
where E: Display,



impl<T, E> Display for TryReadyChunksError<T, E>
where E: Display,



impl<T, Item> Display for ReuniteError<T, Item>



impl<T, U> Display for OwnedMappedMutexGuard<T, U>
where U: Display + ?Sized, T: ?Sized,



impl<T, U> Display for OwnedRwLockMappedWriteGuard<T, U>
where U: Display + ?Sized, T: ?Sized,



impl<T, U> Display for OwnedRwLockReadGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,



impl<T> Display for AsyncFdTryNewError<T>



impl<T> Display for Bound<'_, T>



impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for compio::buf::arrayvec::CapacityError<T>

Source

impl<T> Display for DispatchError<T>



impl<T> Display for DisplayValue<T>
where T: Display,



impl<T> Display for Error<T>
where T: Debug,



impl<T> Display for Error<T>
where T: Debug,



impl<T> Display for ForcePushError<T>

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for compio::tls::rustls::lock::MutexGuard<'_, T>
where T: Display + ?Sized,



impl<T> Display for MutexGuard<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>



impl<T> Display for OwnedMutexGuard<T>
where T: Display + ?Sized,



impl<T> Display for OwnedRwLockWriteGuard<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>



impl<T> Display for Port<T>



impl<T> Display for PushError<T>



impl<T> Display for Py<T>
where T: PyTypeInfo,

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,



impl<T> Display for ReuniteError<T>

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for std::sync::mpsc::SendError<T>



impl<T> Display for SendError<T>



impl<T> Display for SendError<T>



impl<T> Display for SendError<T>



impl<T> Display for SendError<T>

Source

impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>



impl<T> Display for SendTimeoutError<T>



impl<T> Display for SendTimeoutError<T>

Available on crate feature time only.


impl<T> Display for SetError<T>



impl<T> Display for SetOnceError<T>



impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,



impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,



impl<T> Display for ThinCell<T>
where T: Display + ?Sized,



impl<T> Display for ThinCell<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for std::sync::mpsc::TrySendError<T>



impl<T> Display for TrySendError<T>



impl<T> Display for TrySendError<T>



impl<T> Display for TrySendError<T>



impl<T> Display for Unalign<T>
where T: Unaligned + Display,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<const CAP: usize> Display for ArrayString<CAP>



impl<const MAX_SIZE: usize> Display for ObjectIdentifier<MAX_SIZE>